@@ -7,7 +7,7 @@ A collection of analytical functions with 2 or more available fidelities.
 """
 import pkg_resources
 
-from .multiFidelityFunction import MultiFidelityFunction
+from .multi_fidelity_function import MultiFidelityFunction, invert
 from .borehole import borehole
 from .currin import currin
 from .park91a import park91a
@@ -16,8 +16,7 @@ from .bohachevsky import bohachevsky
 from .branin import branin
 from .booth import booth
 from .forrester import forrester, Forrester
-from .himmelblau import himmelblau, himmelblau_3f
-from .himmelblau_seb import himmelblau_seb
+from .himmelblau import himmelblau
 from .six_hump_camelback import six_hump_camelback
 from .hartmann import hartmann6
 
@@ -46,8 +45,3 @@ bi_fidelity_functions = (
     # 8D
     borehole,
 )
-
-tri_fidelity_functions = (
-    himmelblau_3f,
-    himmelblau_seb,
-)
