@@ -1,20 +1,30 @@
 # -*- coding: utf-8 -*-
 
-"""Implementation of the adjustable bi-fidelity Paciorek function
+r"""Implementation of the adjustable bi-fidelity Paciorek function
 as defined in:
 
     Toal, D.J.J. Some considerations regarding the use of multi-
     fidelity Kriging in the construction of surrogate models.
     Struct Multidisc Optim 51, 1223–1245 (2015)
     doi:10.1007/s00158-014-1209-5
+
+Function definitions:
+
+.. math::
+
+    f_h(x_1, x_2) = \sin \Big( \dfrac{1}{x_1x_2} \Big)
+
+.. math::
+
+    f_l(x_1, x_2) = f_h(x_1, x_2) - 9a^2\cos \Big( \dfrac{1}{x_1x_2} \Big)
+
+where :math:`a \in (0, 1]` is the adjustable parameter
 """
 
 
-from functools import partial
-
 import numpy as np
 
-from mf2.multiFidelityFunction import MultiFidelityFunction
+from mf2.multi_fidelity_function import AdjustableMultiFidelityFunction
 
 
 def paciorek_hf(xx):
@@ -24,12 +34,12 @@ def paciorek_hf(xx):
     return np.sin(1/(x1*x2))
 
 
-def adjustable_paciorek_lf(xx, a2):
+def adjustable_paciorek_lf(xx, a):
     xx = np.atleast_2d(xx)
 
     x1, x2 = xx.T
     temp1 = paciorek_hf(xx)
-    temp2 = 9 * a2**2
+    temp2 = 9 * a ** 2
     temp3 = np.cos(1/(x1*x2))
     return temp1 - (temp2*temp3)
 
@@ -37,9 +47,9 @@ def adjustable_paciorek_lf(xx, a2):
 u_bound = [1]*2
 l_bound = [0.3]*2
 
+x_opt = [0.460658865961780639020326, 0.460658865961780639020326]  # sqrt(3pi/2)
 
-def paciorek(a2):
-    """Factory method for adjustable Paciorek function using parameter value `a2`
+docstring = """Factory method for adjustable Paciorek function using parameter value `a2`
 
     :param a2:  Parameter to tune the correlation between high- and low-fidelity
                 functions. Expected values lie in range [0, 1]. High- and low-
@@ -47,9 +57,11 @@ def paciorek(a2):
     :return:    A MultiFidelityFunction instance
     """
 
-    return MultiFidelityFunction(
-        f"adjustable Paciorek {a2}",
-        u_bound, l_bound,
-        [paciorek_hf, partial(adjustable_paciorek_lf, a2=a2)],
-        fidelity_names=['high', 'low'],
-    )
+paciorek = AdjustableMultiFidelityFunction(
+    "Paciorek",
+    u_bound, l_bound,
+    [paciorek_hf],
+    [adjustable_paciorek_lf],
+    fidelity_names=['high', 'low'],
+    x_opt=x_opt,
+)
