@@ -5,11 +5,21 @@
     Dong, H., Song, B., Wang, P. et al. Multi-fidelity information
     fusion based on prediction of kriging. Struct Multidisc Optim
     51, 1267–1280 (2015) doi:10.1007/s00158-014-1213-9
+
+Function definitions:
+
+.. math::
+
+    f_h(x_1, x_2) = (x_1 + 2x_2 - 7)^2 + (2x_1 + x_2 - 5)^2
+
+.. math::
+
+    f_l(x_1, x_2) = f_h(0.4x_1, x_2) + 1.7x_1x_2 - x_1 + 2x_2
 """
 
 import numpy as np
 
-from .multiFidelityFunction import MultiFidelityFunction
+from .multi_fidelity_function import MultiFidelityFunction
 
 
 def booth_hf(xx):
@@ -54,10 +64,13 @@ l_bound = [-10, -10]
 #: Upper bound for Booth function
 u_bound = [ 10,  10]
 
+x_opt = [1, 3]
+
 #: 2D Booth function with fidelities 'high' and 'low'
 booth = MultiFidelityFunction(
     "booth",
     u_bound, l_bound,
     [booth_hf, booth_lf],
-    fidelity_names=['high', 'low']
+    fidelity_names=['high', 'low'],
+    x_opt=x_opt,
 )
